@@ -190,7 +190,7 @@ class SpiderController(Thread):
         if request.callback and isinstance(request.callback, str) and hasattr(self.spider, request.callback):
             callback = getattr(self.spider,request.callback)
 
-            if inspect.isgeneratorfunction(request.callback):  # 很好用的库，判断是否是 yield 函数
+            if inspect.isgeneratorfunction(callback):  # 很好用的库，判断是否是 yield 函数
                 for task in callback(request, response):
                     self.parse_task(task=task, request=request, response=response)
             else:
