@@ -144,7 +144,7 @@ class JumpController:
         if request.callback and isinstance(request.callback, str) and hasattr(self.spider, request.callback):
             callback = getattr(self.spider, request.callback)
 
-            if inspect.isgeneratorfunction(request.callback):  # 很好用的库，判断是否是 yield 函数
+            if inspect.isgeneratorfunction(callback):  # 很好用的库，判断是否是 yield 函数
                 for task in callback(request, response):
                     if isinstance(task, Request):
                         self.add_new_request(new_request=task, old_request=request, response=response)
